@@ -20,13 +20,18 @@ def pytest_exception_interact(node, call, report):
         thread = threading.current_thread()
         frames_by_id = dict([(id(frame), frame) for frame in frames])
         frame = frames[-1]
-        thread.additionalInfo.exception = (exctype, value, traceback)
-        thread.additionalInfo.pydev_force_stop_at_exception = (frame, frames_by_id)
-        thread.additionalInfo.message = "test fail"
-        debugger = pydevd.debugger
-        debugger.force_post_mortem_stop += 1
-
-        pydevd_tracing.SetTrace(None)
-        debugger.handle_post_mortem_stop(thread.additionalInfo, thread)
+        exception = (exctype, value, traceback)
+        if hasattr(thread, "additional_info"):
+            thread.additional_info.pydev_message = "test fail"
+        try:
+            debugger = pydevd.debugger
+        except AttributeError:
+            debugger = pydevd.get_global_debugger()
+        pydevd_tracing.SetTrace(None)  # no tracing from here
+        try:
+            debugger.stop_on_unhandled_exception(thread, frame, frames_by_id, exception)
+        except AttributeError:
+            # fallback to pre PyCharm 2019.2 API
+            debugger.handle_post_mortem_stop(thread, frame, frames_by_id, exception)
 
     return report
